==> nextcloud-30.0.12.tgz: nextcloud/apps/dashboard/l10n/uz.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Boshqaruv paneli",
    "Dashboard app" : "Boshqaruv paneli ilovasi",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Kuningizni xabardorlik bilan boshlang\n\nNextcloud Dashboard - bu kunning boshlang'ich nuqtasi bo'lib, sizga bo'lajak uchrashuvlar, shoshilinch elektron pochta xabarlari, chat xabarlari, kiruvchi chiptalar, so'nggi tvitlar va boshqalar haqida umumiy ma'lumot beradi! Odamlar o'zlari yoqtirgan vidjetlarni qo'shishlari va fonni o'z xohishlariga ko'ra o'zgartirishlari mumkin.",
    "Weather" : "Ob-havo",
    "Status" : "Status",
    "Good morning" : "Xayrli tong",
    "Good morning, {name}" : "Xayrli tong, {name}",
    "Good afternoon" : "Hayrli kun",
    "Good afternoon, {name}" : "Hayrli kun, {name}",
    "Good evening" : "Hayrli kech",
    "Good evening, {name}" : "Hayrli kech, {name}",
    "Hello" : "Assalomu aleykum",
    "Hello, {name}" : "Assalomu aleykum, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Tug'ilgan kun muborak bo'lsin 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Tug'ilgan kun muborak bo'lsin, {name} 🥳🤩🎂🎉",
    "Customize" : "Moslashtirish",
    "Edit widgets" : "Vidjetlarni tahrirlash",
    "Get more widgets from the App Store" : "App Store'dan ko'proq vidjetlarni oling",
    "Weather service" : "Ob-havo xizmati",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Maxfiyligingiz uchun ob-havo maʼlumotlari sizning nomingizdan Nextcloud serveringiz tomonidan soʻraladi, shuning uchun ob-havo xizmati shaxsiy maʼlumotlarni olmaydi.",
    "Weather data from Met.no" : "Met.no dan ob-havo ma'lumotlari",
    "geocoding with Nominatim" : "Nominatim bilan geokodlash",
    "elevation data from OpenTopoData" : "OpenTopoData dan balandlik ma'lumotlari"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.9.tgz: nextcloud/apps/dashboard/l10n/uz.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Boshqaruv paneli",
    "Dashboard app" : "Boshqaruv paneli ilovasi",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Kuningizni xabardorlik bilan boshlang\n\nNextcloud Dashboard - bu kunning boshlang'ich nuqtasi bo'lib, sizga bo'lajak uchrashuvlar, shoshilinch elektron pochta xabarlari, chat xabarlari, kiruvchi chiptalar, so'nggi tvitlar va boshqalar haqida umumiy ma'lumot beradi! Odamlar o'zlari yoqtirgan vidjetlarni qo'shishlari va fonni o'z xohishlariga ko'ra o'zgartirishlari mumkin.",
    "Weather" : "Ob-havo",
    "Status" : "Status",
    "Good morning" : "Xayrli tong",
    "Good morning, {name}" : "Xayrli tong, {name}",
    "Good afternoon" : "Hayrli kun",
    "Good afternoon, {name}" : "Hayrli kun, {name}",
    "Good evening" : "Hayrli kech",
    "Good evening, {name}" : "Hayrli kech, {name}",
    "Hello" : "Assalomu aleykum",
    "Hello, {name}" : "Assalomu aleykum, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Tug'ilgan kun muborak bo'lsin 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Tug'ilgan kun muborak bo'lsin, {name} 🥳🤩🎂🎉",
    "Customize" : "Moslashtirish",
    "Edit widgets" : "Vidjetlarni tahrirlash",
    "Get more widgets from the App Store" : "App Store'dan ko'proq vidjetlarni oling",
    "Weather service" : "Ob-havo xizmati",
    "Weather data from Met.no" : "Met.no dan ob-havo ma'lumotlari",
    "geocoding with Nominatim" : "Nominatim bilan geokodlash",
    "elevation data from OpenTopoData" : "OpenTopoData dan balandlik ma'lumotlari",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Maxfiyligingiz uchun ob-havo maʼlumotlari sizning nomingizdan Nextcloud serveringiz tomonidan soʻraladi, shuning uchun ob-havo xizmati shaxsiy maʼlumotlarni olmaydi."
},
"nplurals=1; plural=0;");
